@@ -21,6 +21,7 @@
 #include <QAction>
 #include <QMenuBar>
 #include <QPointer>
+#include <kxmlgui_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -34,17 +35,17 @@ MainWindow::MainWindow()
 
     setCentralWidget(mMainWidget);
 
-    initActions();
 
     setStandardToolBarMenuEnabled(true);
 
     toolBar()->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
 
+    initActions();
     setupGUI(Save | Create, QStringLiteral("kaddressbookui.rc"));
 
     setAutoSaveSettings();
 
-    mHideMenuBarAction->setChecked(Settings::self()->showMenuBar());
+    mShowMenuBarAction->setChecked(Settings::self()->showMenuBar());
     slotToggleMenubar(true);
 #ifdef WITH_KUSERFEEDBACK
     auto userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
@@ -64,7 +65,7 @@ MainWidget *MainWindow::mainWidget() const
 void MainWindow::initActions()
 {
     KStandardAction::quit(this, &MainWindow::close, actionCollection());
-    mHideMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
+    mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
 
     QAction *action = KStandardAction::keyBindings(this, &MainWindow::configureKeyBindings, actionCollection());
     action->setWhatsThis(i18nc("@info:whatsthis",
@@ -72,6 +73,32 @@ void MainWindow::initActions()
                                "the application-wide shortcuts."));
     KStandardAction::configureToolbars(this, &MainWindow::configureToolbars, actionCollection());
     KStandardAction::preferences(this, &MainWindow::configure, actionCollection());
+    if (menuBar()) {
+        mHamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, actionCollection());
+        mHamburgerMenu->setShowMenuBarAction(mShowMenuBarAction);
+        mHamburgerMenu->setMenuBar(menuBar());
+        connect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, [this]() {
+            updateHamburgerMenu();
+            // Immediately disconnect. We only need to run this once, but on demand.
+            // NOTE: The nullptr at the end disconnects all connections between
+            // q and mHamburgerMenu's aboutToShowMenu signal.
+            disconnect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, nullptr);
+        });
+    }
+}
+
+void MainWindow::updateHamburgerMenu()
+{
+    QMenu *menu = new QMenu;
+    menu->addAction(actionCollection()->action(QStringLiteral("akonadi_resource_create")));
+    menu->addSeparator();
+
+    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Print))));
+    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::PrintPreview))));
+    menu->addSeparator();
+
+    menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    mHamburgerMenu->setMenu(menu);
 }
 
 void MainWindow::configure()
@@ -81,9 +108,16 @@ void MainWindow::configure()
 
 void MainWindow::configureKeyBindings()
 {
-    if (KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this)) {
+    KShortcutsDialog *dlg = new KShortcutsDialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
+    dlg->setAttribute(Qt::WA_DeleteOnClose);
+    dlg->setModal(false);
+    dlg->addCollection(actionCollection());
+
+    connect(dlg, &KShortcutsDialog::saved, this, [this]() {
         mMainWidget->updateQuickSearchText();
-    }
+    });
+
+    dlg->configure(true /* save settings on accept*/);
 }
 
 void MainWindow::configureToolbars()
@@ -107,11 +141,11 @@ void MainWindow::newToolbarConfig()
 void MainWindow::slotToggleMenubar(bool dontShowWarning)
 {
     if (menuBar()) {
-        if (mHideMenuBarAction->isChecked()) {
+        if (mShowMenuBarAction->isChecked()) {
             menuBar()->show();
         } else {
-            if (!dontShowWarning) {
-                const QString accel = mHideMenuBarAction->shortcut().toString();
+            if (!dontShowWarning && (!toolBar()->isVisible() || !toolBar()->actions().contains(mHamburgerMenu))) {
+                const QString accel = mShowMenuBarAction->shortcut().toString();
                 KMessageBox::information(this,
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
@@ -121,6 +155,6 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
             }
             menuBar()->hide();
         }
-        Settings::self()->setShowMenuBar(mHideMenuBarAction->isChecked());
+        Settings::self()->setShowMenuBar(mShowMenuBarAction->isChecked());
     }
 }
