@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef MIKESSTYLE_H
-#define MIKESSTYLE_H
+#pragma once
 
 #include "printstyle.h"
 
@@ -36,4 +35,3 @@ public:
 };
 }
 
-#endif
